@@ -2,6 +2,11 @@
 
 import locale
 
+localeOverrides = {
+                   'en': 'CP1252',
+                   'ru': 'CP1251',
+                  }
+
 class ACEEncodingDecodeException(Exception): #{{{1
     def __init__(self, encoding):
         self.msgsource = 'Error decoding string'
@@ -13,10 +18,12 @@ class ACEEncodingDecodeException(Exception): #{{{1
 class ACEEncoding(): #{{{1
     def __init__(self): #{{{2
         sys_locale   = locale.getdefaultlocale()
-        sys_encoding = locale.normalize(sys_locale[0]).split('.')[1]
+        sys_language = sys_locale[0][0:2]
 
-        if sys_locale[0][0:2] == 'en':
-            sys_encoding = 'CP1252'
+        if sys_language in localeOverrides:
+            sys_encoding = localeOverrides[sys_language]
+        else:
+            sys_encoding = locale.normalize(sys_locale[0]).split('.')[1]
 
         self._encoding = sys_encoding
         self._sysEncoding = sys_encoding
