@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 
 import errno
 import sys
@@ -17,29 +16,9 @@ from ACE_file      import ACEFile, ACEFileReadException
 from ACE_utils     import apply_blacklist
 from ACE_settings  import ACESettings
 from ACE_encoding  import ACEEncodingDecodeException
+from ACE_languages import ACELanguages
 
-version = '0.0.11'
-
-langLookup = {
-    3: QString.fromUtf8('English (United Kingdom)'),
-    4: QString.fromUtf8('Français (France)'),
-    5: QString.fromUtf8('Deutsch (Deutschland)'),
-    6: QString.fromUtf8('Español (España)'),
-    8: QString.fromUtf8('Português (Portugal)'),
-    9: QString.fromUtf8('Svenska (Sverige)'),
-    10: QString.fromUtf8('Suomi (Suomi)'),
-    11: QString.fromUtf8('Norsk (Norge)'),
-    12: QString.fromUtf8('Dansk (Danmark)'),
-    13: QString.fromUtf8('Nederlands (Nederland)'),
-    14: QString.fromUtf8('Ελληνικά (Ελλάδα)'),
-    22: QString.fromUtf8('Polski (Polska)'),
-    23: QString.fromUtf8('Čeština (Česká republika)'),
-    39: QString.fromUtf8('Русский (Россия)'),
-    46: QString.fromUtf8('English (United States of America)'),
-    47: QString.fromUtf8('Italiano (Italia)'),
-    51: QString.fromUtf8('Español (América Latina)'),
-    52: QString.fromUtf8('Français (Québec)'),
-}
+version = '0.0.12'
 
 delModes = QStringList(('Normal', 'Confirm', 'OnClick', 'Blacklist'))
 encodings = QStringList(('Default', 'CP1251', 'CP1252', 'CP1253', 'CP1254', 'CP1255', 'CP1256', 'CP1257', 'CP1258', 'CP874', 'ISO8859-1', 'ISO8859-2', 'ISO8859-3', 'ISO8859-4', 'ISO8859-5', 'ISO8859-6', 'ISO8859-7', 'ISO8859-8', 'ISO8859-9', 'ISO8859-10', 'ISO8859-11', 'ISO8859-13', 'ISO8859-14', 'ISO8859-15', 'ISO8859-16', 'UTF-8'))
@@ -166,6 +145,8 @@ class ACEViewWindow(QWidget): #{{{1
         if self.maemo:
             self.setAttribute(Qt.WA_Maemo5StackedWindow);
 
+        self._languages = ACELanguages()
+
     def _applyDeleteMode(self): #{{{2
         if self.newDelMode != self.delMode:
             if self.delMode == 'OnClick':
@@ -183,11 +164,13 @@ class ACEViewWindow(QWidget): #{{{1
             self.delMode = self.newDelMode
 
     def _getLangName(self, langId): #{{{2
-        if langId in langLookup:
-            return langLookup[langId]
-        else:
+        langName = self._languages.getNameFromID(langId)
+
+        if langName == None:
             QMessageBox.information(self, 'Unknown dictionary', QString('An unknown dictionary ID has been found.\nPlease contact\n\tRobin Hill <maemo@robinhill.me.uk>\nwith:\n\t- the ID: %1\n\t- the dictionary language you have selected (from Settings/Text input)').arg(langId))
             return 'Unknown'
+        else:
+            return QString.fromUtf8(langName)
 
     def addEntry(self, checked): #{{{2
         dlg = QDialog(self)
